@@ -10,13 +10,14 @@ from .presolver import presolver as presolver_file
 from .solver import solver as solver_file
 from .centerline import centerline as centerline_file
 from .rom import rom as rom_file
+from .flow import flow as flow_file
 
 def build(paths,radii,normals,options,setup_file=setup_file,
           path_file=path_file,contour_file=contour_file.split("\n"),
           geometry_file=geometry_file,loft_file=loft_file,
           solid_file=solid_file,mesh_file=mesh_file,
           presolver_file=presolver_file,solver_file=solver_file,
-          centerline_file=centerline_file,rom_file=rom_file):
+          centerline_file=centerline_file,rom_file=rom_file,flow_file=flow_file):
     cco_filename = options.filename
     if options.directory_constructor['create_main_folder']:
         os.mkdir(options.directory_constructor['main_folder'])
@@ -111,6 +112,7 @@ def build(paths,radii,normals,options,setup_file=setup_file,
                                      options.solver_constructor['print_error_indicators'],
                                      options.solver_constructor['varying_time_from_file'],
                                      options.solver_constructor['step_construction'],
+                                     options.solver_constructor['distal_resistance'],
                                      options.solver_constructor['pressure_coupling'],
                                      options.solver_constructor['backflow_stabilization'],
                                      options.solver_constructor['residual_control'],
@@ -130,11 +132,13 @@ def build(paths,radii,normals,options,setup_file=setup_file,
                                      options.solver_constructor['flow_advection_form'],
                                      options.solver_constructor['quadrature_interior'],
                                      options.solver_constructor['quadrature_boundary'],
-                                     options.directory_constructor['data_folder'],
-                                     options.directory_constructor['data_folder'],
-                                     options.solver_constructor['inflow_file'],
-                                     options.solver_constructor['inflow'],
-                                     options.solver_constructor['inflow'])
+                                     options.directory_constructor['data_folder'])
+    flow_file = flow_file.format(options.directory_constructor['data_folder'],
+                                 options.flow_constructor['inflow_file'],
+                                 options.directory_constructor['data_folder'],
+                                 options.flow_constructor['inflow_file'],
+                                 options.flow_constructor['time'],
+                                 options.flow_constructor['flow'])
     rom_files = 'import sv\n'
     if options.rom_constructor['0D']['create'] or options.rom_constructor['1D']['create']:
         rom_files += "os.mkdir('{}')\n".format(options.directory_constructor['rom_folder'])
@@ -144,13 +148,15 @@ def build(paths,radii,normals,options,setup_file=setup_file,
                                 '0D',
                                 options.directory_constructor['centerline_folder'],
                                 options.directory_constructor['data_folder'],
-                                options.presolver_constructor['inflow_file'],
+                                options.rom_constructor['0D']['inflow_file'],
                                 options.rom_constructor['0D']['time_step'],
                                 options.rom_constructor['0D']['number_time_steps'],
                                 options.directory_constructor['rom_0D_folder'],
                                 options.rom_constructor['0D']['model_order'],
                                 options.rom_constructor['0D']['model_order'],
                                 options.directory_constructor['rom_0D_folder'],
+                                options.directory_constructor['rom_0D_folder'],
+                                options.rom_constructor['0D']['model_order'],
                                 options.directory_constructor['rom_0D_folder'])
         rom_files += rom0D
     if options.rom_constructor['1D']['create']:
@@ -159,13 +165,15 @@ def build(paths,radii,normals,options,setup_file=setup_file,
                                 '1D',
                                 options.directory_constructor['centerline_folder'],
                                 options.directory_constructor['data_folder'],
-                                options.presolver_constructor['inflow_file'],
+                                options.rom_constructor['1D']['inflow_file'],
                                 options.rom_constructor['1D']['time_step'],
                                 options.rom_constructor['1D']['number_time_steps'],
                                 options.directory_constructor['rom_1D_folder'],
                                 options.rom_constructor['1D']['model_order'],
                                 options.rom_constructor['1D']['model_order'],
                                 options.directory_constructor['rom_1D_folder'],
+                                options.directory_constructor['rom_1D_folder'],
+                                options.rom_constructor['1D']['model_order'],
                                 options.directory_constructor['rom_1D_folder'])
         rom_files += rom1D
     #postsolver_file = open('postsolver.txt','r').read()
@@ -239,12 +247,19 @@ def build(paths,radii,normals,options,setup_file=setup_file,
     cco_file_text += solver_file
     ############################################################
 
+    ############################################################
+    # BUILD INFLOW FILES
+    ############################################################
+    cco_file_text += flow_file
+    ############################################################
+
     ############################################################
     # EXTRACT CENTERLINE
     ############################################################
     cco_file_text += centerline_file
     ############################################################
 
+
     ############################################################
     # BUILDING ROM INPUT FILES
     ############################################################
