@@ -14,9 +14,11 @@ from .branch_addition.add_branches_v3 import *
 from .sv_interface.get_sv_data import *
 from .sv_interface.options import *
 from .sv_interface.build_files import *
+from .sv_interface.waveform import generate_physiologic_wave
 from copy import deepcopy
 from itertools import combinations
 from tqdm import tqdm
+import pickle
 
 class tree:
     """
@@ -43,20 +45,31 @@ class tree:
     # index: 30    -> self identifying index (-1 if intermediate)
     """
     def __init__(self):
-        self.parameters = {'gamma'   : 3.0,
-                           'lambda'  : 2.0,
-                           'mu'      : 1.0,
-                           'nu'      : 3.6/100,
-                           'Pperm'   : 100*1333.22,
-                           'Pterm'   : 60*1333.22,
-                           'Qterm'   : (0.125)/60,
-                           'edge_num': 0}
-
+        #self.parameters = {'gamma'   : 3.0,
+        #                   'lambda'  : 2.0,
+        #                   'mu'      : 1.0,
+        #                   'nu'      : 3.6/100,
+        #                   'Pperm'   : 100*1333.22,
+        #                   'Pterm'   : 60*1333.22,
+        #                   'Qterm'   : (0.125)/60,
+        #                   'edge_num': 0}
+        self.set_parameters()
         self.data = np.zeros((1,31))
         self.radius_buffer = 0.1
         self.fraction = None
         self.set_assumptions()
 
+    def set_parameters(self,**kwargs):
+        self.parameters = {}
+        self.parameters['gamma']    = kwargs.get('gamma',3.0)
+        self.parameters['lambda']   = kwargs.get('lambda',2.0)
+        self.parameters['mu']       = kwargs.get('mu',1.0)
+        self.parameters['nu']       = kwargs.get('nu',3.6)/100
+        self.parameters['Pperm']    = kwargs.get('Pperm',100)*1333.22
+        self.parameters['Pterm']    = kwargs.get('Pterm',60)*1333.22
+        self.parameters['Qterm']    = kwargs.get('Qterm',0.125)/60
+        self.parameters['edge_num'] = kwargs.get('edge_num',0)
+
     def set_assumptions(self,**kwargs):
         self.homogeneous = kwargs.get('homogeneous',True)
         self.directed    = kwargs.get('directed',False)
@@ -67,7 +80,7 @@ class tree:
 
     def show_assumptions(self):
         print('homogeneous : {}'.format(self.homogeneous))
-        print('directed    : {}'.format(self.diected))
+        print('directed    : {}'.format(self.directed))
         print('convex      : {}'.format(self.convex))
         print('hollow      : {}'.format(self.hollow))
         print('dimension   : {}'.format(self.dimension))
@@ -197,11 +210,23 @@ class tree:
         self.boundary = pickle.loads(file)
         file.close()
 
-    def export(self,gui=True):
+    def export(self,steady=True,apply_distal_resistance=True,gui=True):
         interps,frames,branches = get_interpolated_sv_data(self.data)
         points,radii,normals    = sv_data(interps,radius_buffer=self.radius_buffer)
-        inflow = self.data[0,22]
-        build(points,radii,normals,file_options(inflow=inflow,gui=gui))
+        if steady:
+            time = [0, 1]
+            flow = [self.data[0,22], self.data[0,22]]
+        else:
+            time,flow = generate_physiologic_wave(self.data[0,22],self.data[0,21]*2)
+            time = time.tolist()
+            flow = flow.tolist()
+            flow[-1] = flow[0]
+        if apply_distal_resistance:
+            R = self.parameters['Pterm']/self.data[0,22]
+        else:
+            R = 0
+        options = file_options(time=time,flow=flow,gui=gui,distal_resistance=R)
+        build(points,radii,normals,options)
 
     def collision_free(self,outside_vessels):
         return no_outside_collision(self,outside_vessels)
